package com.zhilian.resolver.service.impl.eventGeofence;

import com.zhilian.business.domain.Fence;
import com.zhilian.business.domain.vo.FenceVo;
import com.zhilian.common.resolver.domain.ResolverReportData;
import com.zhilian.resolver.service.ResolverEventService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.List;

import static java.lang.Double.parseDouble;

/**
  * @ClassName GeofenceEventServiceImpl
  * @Description 电子围栏事件
  * @Author Can.J
  * @Date  2024/4/4 10:25
 */
@Slf4j
@Service("geofence")
public class GeofenceEventServiceImpl implements ResolverEventService {
//    @Autowired
//    private FenceMapper fenceMapper;

    @Override
    public void execute(ResolverReportData resolverReportData) {
        log.info("电子围挡执行");
        String vin = resolverReportData.getVin();
        log.info("vin :"+vin);
        //经度
        double pointLng = parseDouble(resolverReportData.getLongitude());
        //维度
        double pointLat = parseDouble(resolverReportData.getLatitude());
        FenceVo fenceVo = new FenceVo();

//        List<Fence> list=fenceMapper.fenceList(fenceVo);
//
//        for (Fence fence : list) {
//            if (fence.getVin().equals(vin)){
//                String[] split = fence.getFenceMessage().split(";");
//
//                boolean withinFence = isWithinFence(pointLat, pointLng, Arrays.asList(split));
//
//                if(withinFence){
//                    log.info("在围栏内");
//                }else {
//                    log.error("不在围栏内");
//                }
//            }
//        }
        log.info("电子围挡结束");
    }

    @Override
    public String getEventName() {
        return "geofence";
    }

        public boolean isWithinFence(double pointLat, double pointLng, List<String> split){
        if(split.size()<4){
            throw new IllegalArgumentException("不符合条件");
        }

        double[] longitudes = new double[4];
        double[] latitudes = new double[4];

        for (int i = 0; i < 4; i++) {
            String[] coordinates = split.get(i).split(",");
            latitudes[i] = parseDouble(coordinates[0]);
            longitudes[i] = parseDouble(coordinates[1]);
        }

        return isPointInRectangle(pointLat,pointLat,latitudes,longitudes);
    }

    private boolean isPointInRectangle(double pointLat, double pointLng, double[] latitudes, double[] longitudes) {
        // 根据矩形顶点顺序确定最小和最大纬度、经度
        double minLatitude = Arrays.stream(latitudes).min().orElseThrow();
        double maxLatitude = Arrays.stream(latitudes).max().orElseThrow();
        double minLongitude = Arrays.stream(longitudes).min().orElseThrow();
        double maxLongitude = Arrays.stream(longitudes).max().orElseThrow();

        return pointLat >= minLatitude && pointLat <= maxLatitude &&
                pointLng >= minLongitude && pointLng <= maxLongitude;
    }
}
