package com.zhilian.resolver.service.impl.eventMalfunction;

import com.alibaba.fastjson.JSON;
import com.zhilian.common.redis.service.RedisService;
import com.zhilian.common.resolver.domain.ErrorCar;
import com.zhilian.common.resolver.domain.ResolverReportData;
import com.zhilian.common.resolver.domain.SysUserEnhancedServices;
import com.zhilian.resolver.mapper.UserMapper;
import com.zhilian.resolver.service.ResolverEventService;
import com.zhilian.resolver.service.ResolverReportInfoService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.concurrent.TimeUnit;

/**
  * @ClassName MalfunctionEventServiceImpl
  * @Description 故障事件服务
  * @Author Can.J
  * @Date  2024/4/4 10:00
 */
@Slf4j
@Service("malfunction")
public class MalfunctionEventServiceImpl implements ResolverEventService {
    @Autowired
    private RedisService redisService;

    /**
     *  获取用信息 模拟故障
     */
    @Autowired
    private UserMapper userMapper;

    /**
     *  注入ResolverReportInfoService 业务层
     */
    @Autowired
    private ResolverReportInfoService resolverReportInfoService;

    @Override
    public void execute(ResolverReportData vehicleData) {
        log.info("故障事件开始执行");
                if(isAnyFieldZero(vehicleData)){
                    resolverReportInfoService.saveDataToDatabaseByMalfunction(vehicleData);


                    ErrorCar errorCar = new ErrorCar();
                    errorCar.setVin(vehicleData.getVin());
                    //     * 车辆状态 1：正常 0：故障
                    if(vehicleData.getVehicleStatus()==0){
                        errorCar.setCode("GZ001");
                        errorCar.setLevel(1);
                    }

                    //     * 充电状态 1：正常 0：故障
                    //    private int chargingStatus;
                    if(vehicleData.getChargingStatus()==0){
                        errorCar.setCode("GZ001");
                        errorCar.setLevel(1);
                    }

                    //     * 运行状态 1：正常 0：故障
                    if(vehicleData.getOperatingStatus()==0){
                        errorCar.setCode("GZ002");
                        errorCar.setLevel(3);
                    }

                    //     * SOC 状态 1：正常 0：故障
                    if(vehicleData.getSocStatus()==0){
                        errorCar.setCode("GZ003");
                        errorCar.setLevel(3);
                    }
                    //
                    //    /**
                    //     *  可充电储能装置工作状态 1：正常 0：故障
                    //     */
                    //    private int chargingEnergyStorageStatus;
                    //
                    //    /**
                    //     *  驱动电机状态 1：正常 0：故障
                    //     */
                    //    private int driveMotorStatus;
                    //
                    //    /**
                    //     * 定位是否有效 1：有效 0：无效
                    //     */
                    //    private int positionStatus;
                    //
                    //    /**
                    //     * EAS(汽车防盗系统)状态 1：正常 0：故障
                    //     */
                    //    private int easStatus;
                    //
                    //    /**
                    //     * PTC(电动加热器)状态 1：正常 0：故障
                    //     */
                    //    private int ptcStatus;
                    //
                    //    /**
                    //     * EPS(电动助力系统)状态 1：正常 0：故障
                    //     */
                    //    private int epsStatus;
                    //
                    //    /**
                    //     * ABS(防抱死)状态 1：正常 0：故障
                    //     */
                    //    private int absStatus;
                    //
                    //    /**
                    //     *  MCU(电机/逆变器)状态 1：正常 0：故障
                    //     */
                    //    private int mcuStatus;
                    //
                    //    /**
                    //     *  动力电池加热状态 1：正常 0：故障
                    //     */
                    //    private int heatingStatus;
                    //
                    //    /**
                    //     * 动力电池当前状态 1：正常 0：故障
                    //     */
                    //    private int batteryStatus;
                    //
                    //    /**
                    //     *  动力电池保温状态 1：正常 0：故障
                    //     */
                    //    private int batteryInsulationStatus;
                    //
                    //    /**
                    //     *  DCDC(电力交换系统) 状态 1：正常 0：故障
                    //     */
                    //    private int dcdcStatus;
                    //
                    //    /**
                    //     * CHG(充电机)状态 1：正常 0：故障
                    //     */
                    //    private int chgStatus;
                    String key = "breakdown";
                    String value = JSON.toJSONString(errorCar);
                    redisService.setCacheObject(key,value);
                    long expireTime = 30;
                    redisService.expire(key, expireTime, TimeUnit.MINUTES);

                }


        log.info("故障事件结束");

    }
    private boolean isAnyFieldZero(ResolverReportData resolverReportData) {
        return resolverReportData.getChargingStatus() == 0 ||
                resolverReportData.getOperatingStatus() == 0 ||
                resolverReportData.getSocStatus() == 0 ||
                resolverReportData.getVehicleStatus() == 0 ||
                resolverReportData.getChargingEnergyStorageStatus() == 0 ||
                resolverReportData.getDriveMotorStatus() == 0 ||
                resolverReportData.getPositionStatus() == 0 ||
                resolverReportData.getEasStatus() == 0 ||
                resolverReportData.getPtcStatus() == 0 ||
                resolverReportData.getEpsStatus() == 0 ||
                resolverReportData.getAbsStatus() == 0 ||
                resolverReportData.getMcuStatus() == 0 ||
                resolverReportData.getHeatingStatus() == 0 ||
                resolverReportData.getBatteryStatus() == 0 ||
                resolverReportData.getBatteryInsulationStatus() == 0 ||
                resolverReportData.getDcdcStatus() == 0 ||
                resolverReportData.getChgStatus() == 0;

    }
    @Override
    public String getEventName() {
        return "malfunction";
    }
}
